Command Line Interface
======================
element_coder automatically installs the command :code:`element_coder`. See
:code:`element_coder --help` for usage details.

.. click:: element_coder.cli:encode_cli
   :prog: element_coder
   :show-nested:

.. click:: element_coder.cli:decode_cli
   :prog: element_coder
   :show-nested:
